@@ -45,7 +45,7 @@ module Rabbit
     def_delegators(:@renderer, :redraw, :clear_slide)
     def_delegators(:@renderer, :cursor=, :filename, :filename=)
     def_delegators(:@renderer, :each_slide_pixbuf)
-    def_delegators(:@renderer, :off_screen_canvas)
+    def_delegators(:@renderer, :offscreen_canvas)
     def_delegators(:@renderer, :foreground, :background)
     def_delegators(:@renderer, :foreground=, :background=)
     def_delegators(:@renderer, :background_image, :background_image=)
@@ -66,6 +66,7 @@ module Rabbit
     def_delegators(:@renderer, :draw_rounded_rectangle)
     def_delegators(:@renderer, :draw_rsvg_handle)
     def_delegators(:@renderer, :draw_poppler_page)
+    def_delegators(:@renderer, :draw_link)
 
     def_delegators(:@renderer, :draw_cube, :draw_sphere, :draw_cone)
     def_delegators(:@renderer, :draw_torus, :draw_tetrahedron)
