@@ -57,14 +57,10 @@ module Rabbit
     end
 
     def fullscreen
-      @fullscreen_toggled = false
-      @fullscreen = true
       @window.fullscreen
     end
 
     def unfullscreen
-      @fullscreen_toggled = false
-      @fullscreen = false
       @window.unfullscreen
     end
 
@@ -77,11 +73,7 @@ module Rabbit
     end
 
     def fullscreen?
-      if @window.respond_to?(:fullscreen?)
-        @window.fullscreen?
-      else
-        @fullscreen
-      end
+      @fullscreen
     end
 
     def main_window?
@@ -94,9 +86,7 @@ module Rabbit
 
     def init_gui(width, height, main_window, window_type=nil)
       init_window(width, height, window_type)
-      @fullscreen_toggled = false
       @fullscreen = false
-      @iconify = false
       @main_window = main_window
       if @main_window
         @window.keep_above = @force_keep_above unless @force_keep_above.nil?
@@ -132,10 +122,10 @@ module Rabbit
       set_window_signal_destroy
     end
 
-    def update_keep_above(keep_above=nil)
+    def update_keep_above(keep_above)
       if @main_window
         keep_above = @force_keep_above unless @force_keep_above.nil?
-        @window.keep_above = keep_above unless keep_above.nil?
+        @window.keep_above = keep_above
       else
         @window.keep_above = true
       end
@@ -144,23 +134,21 @@ module Rabbit
     def set_window_signal_window_state_event
       @window.signal_connect("window_state_event") do |widget, event|
         if event.changed_mask.fullscreen?
-          @fullscreen_toggled = true
-          if fullscreen?
+          @fullscreen = event.new_window_state.fullscreen?
+          if @fullscreen
             @window.keep_above = true
             @canvas.fullscreened
           else
             update_keep_above(false)
             @canvas.unfullscreened
           end
-          @window.present
         elsif event.changed_mask.iconified?
-          if @iconify
-            @iconify = false
-          else
+          if event.new_window_state.iconified?
             @canvas.iconified
-            @iconify = true
           end
         end
+
+        false
       end
     end
 
@@ -233,9 +221,7 @@ module Rabbit
       @window = Gtk::EventBox.new
       @window.set_size_request(width, height)
       @canvas.attach_to(self, @window)
-      @fullscreen_toggled = false
       @fullscreen = false
-      @iconify = false
       @main_window = main_window
       @window.show
       @canvas.post_init_gui
