@@ -14,15 +14,11 @@ module Rabbit
         def match?(filename)
           return true if File.extname(filename) == ".pdf"
 
-          File.open(filename) do |file|
-            line = file.gets
-            return false if line.nil?
+          File.open(filename, "rb") do |file|
+            data = file.read(10)
+            return false if data.nil?
 
-            begin
-              /\A%PDF-1\.\d\z/ =~ line.chomp
-            rescue ArgumentError
-              false
-            end
+            data.start_with?("%PDF-1.")
           end
         end
       end
@@ -70,13 +66,13 @@ module Rabbit
       end
 
       def uri
-        "file://#{filename}"
+        GLib.filename_to_uri(filename)
       end
 
       def to_pixbuf
         w = original_width
         h = original_height
-        pixbuf = Gdk::Pixbuf.new(Gdk::Pixbuf::COLORSPACE_RGB, true, 8, w, h)
+        pixbuf = GdkPixbuf::Pixbuf.new(:rgb, true, 8, w, h)
         page.render(0, 0, w, h, 1.0, 0, pixbuf)
         pixbuf
       end
