@@ -1,3 +1,19 @@
+# Copyright (C) 2004-2015  Kouhei Sutou <kou@cozmixng.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+
 require "erb"
 require "stringio"
 
@@ -59,7 +75,7 @@ module Rabbit
       name = "JumpTo#{i}"
       label = "#{i}: #{escape_label(Utils.unescape_title(title))}"
       tooltip = _("Jump to the %dth slide") % i
-      action = Gtk::Action.new(name, label, tooltip, nil)
+      action = Gtk::Action.new(name, :label => label, :tooltip => tooltip)
       action.signal_connect("activate") do
         jump_to_action.activate {i}
       end
@@ -86,7 +102,7 @@ module Rabbit
         @jump_to_actions.add_action(action)
         @jump_to_actions_keeper << action # Workaround for > Ruby/GTK2 0.16
         @merge.add_ui(@jump_to_merge_id, jump_to_path, action.name,
-                      action.name, Gtk::UIManager::AUTO, false)
+                      action.name, :auto, false)
       end
     end
 
@@ -129,25 +145,23 @@ module Rabbit
     def theme_menu_add_category(prefix, path, category)
       name = "#{prefix}ThemeCategory#{category}"
       label = _(category)
-      action = Gtk::Action.new(name, label, nil, nil)
+      action = Gtk::Action.new(name, :label => label)
       @theme_actions.add_action(action)
-      @merge.add_ui(@theme_merge_id, path, category, name,
-                    Gtk::UIManager::MENU, false)
+      @merge.add_ui(@theme_merge_id, path, category, name, :menu, false)
     end
 
     def theme_menu_add_theme(prefix, path, entry, canvas)
       path = "#{path}/#{entry.category}"
       name = "#{prefix}ThemeEntry#{entry.name}"
       label = _(entry.title)
-      action = Gtk::Action.new(name, label, nil, nil)
+      action = Gtk::Action.new(name, :label => label)
       action.signal_connect("activate") do
         canvas.activate("#{prefix}Theme") do
           [entry, Utils.process_pending_events_proc]
         end
       end
       @theme_actions.add_action(action)
-      @merge.add_ui(@theme_merge_id, path, entry.name, name,
-                    Gtk::UIManager::AUTO, false)
+      @merge.add_ui(@theme_merge_id, path, entry.name, name, :auto, false)
     end
 
     def show_tearoff(sub_menus=@menu.children)
