@@ -74,6 +74,14 @@ module Rabbit
       def to_gdk_color
         Gdk::Color.new(*to_gdk_rgb)
       end
+
+      def to_css_rgba
+        red_percent = (red * 100).ceil
+        green_percent = (green * 100).ceil
+        blue_percent = (blue * 100).ceil
+        a = alpha || 1.0
+        "rgba(#{red_percent}%, #{green_percent}%, #{blue_percent}%, #{a})"
+      end
     end
   end
 end
