@@ -35,6 +35,11 @@ module Rabbit
           end
         end
 
+        def size
+          refresh_size
+          @size
+        end
+
         def redraw
           widget.queue_draw
         end
@@ -140,7 +145,8 @@ module Rabbit
         private
         def set_drawable(drawable)
           @drawable = drawable
-          w, h = @drawable.size
+          w = @drawable.width
+          h = @drawable.height
           @default_size_ratio = w.to_f / h.to_f
           @size_ratio = @default_size_ratio
           set_size(w, h)
@@ -162,8 +168,9 @@ module Rabbit
         def refresh_size
           return unless @size_dirty
 
-          w, h = @drawable.size
-          @size = Size.new(w, h, @size.ratio)
+          @size = Size.new(@drawable.width,
+                           @drawable.height,
+                           @size.ratio)
           @size_dirty = false
         end
 
