@@ -15,7 +15,7 @@ module Rabbit
 
           pressed_info = nil
           target_button = 3
-          target_event_type = Gdk::Event::Type::BUTTON_PRESS
+          target_event_type = Gdk::EventType::BUTTON_PRESS
           target_info = [target_button, target_event_type]
 
           add_button_press_hook do |event|
