@@ -186,7 +186,12 @@ module Rabbit
             set_source(color, params)
             set_line_options(params)
             @context.move_to(x, y)
-            @context.show_pango_layout(layout)
+            if params[:stroke]
+              @context.pango_layout_path(layout)
+              apply_cairo_action(false, params)
+            else
+              @context.show_pango_layout(layout)
+            end
           end
         end
 
@@ -266,6 +271,16 @@ module Rabbit
           end
         end
 
+        def draw_link(uri)
+          if @context.respond_to?(:tag)
+            @context.tag(::Cairo::Tag::LINK, "uri='#{uri}'") do
+              yield
+            end
+          else
+            yield
+          end
+        end
+
         def make_layout(text)
           attributes, text = Pango.parse_markup(text)
           layout = @context.create_pango_layout
