@@ -7,7 +7,7 @@
 @lightning_talk_contact_information_color ||= nil
 @lightning_talk_contact_information_font_family ||= @font_family
 @lightning_talk_as_large_as_possible ||= false
-@lightning_talk_wrap_mode ||= Pango::Layout::WRAP_WORD
+@lightning_talk_wrap_mode ||= Pango::WrapMode::WORD
 if @lightning_talk_horizontal_centering.nil?
   @lightning_talk_horizontal_centering = true
 end
@@ -99,7 +99,7 @@ def setup_lightning_talk_slide(slide)
               :family => contact_information_family,
             }
             text.font(params)
-            text.align = Pango::Layout::ALIGN_RIGHT
+            text.align = Pango::Alignment::RIGHT
             text.compile(canvas, x, y, w, h)
             text.layout.set_width(width * Pango::SCALE)
             text_x = margin_left
