@@ -1,5 +1,5 @@
 add_image_path("rabbit-images")
 
-@powered_by_images = ["rabbit-banner.png"]
+# @powered_by_images = ["rabbit-banner.png"]
 @powered_by_text = "Powered by Rabbit #{VERSION} and COZMIXNG"
 include_theme("powered-by")
